yakumo.nova.v2.network

Package yakumo :: Package nova :: Package v2 :: Module network |
[hide private]
[frames] | no frames]

# Module network

source code

Resource class and its manager for networks in Compute API v2

Classes | [hide private]
| Resource Resource class for networks in Compute API v2
| Manager Manager class for networks in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('bridge', 'bridge', mapper.Noop), ('bridg
      e_interface', 'bridge_interface', mapper.Noop), ('broadcast', 'broadca
      st', mapper.Noop), ('cidr', 'cidr', mapper.Noop), ('cidr_v6', 'cidr_v6
      ', mapper.Noop), ('dhcp_server', 'dhcp_server', mapper.Noop), ('dhcp_s
      tart', 'dhcp_start', mapper.Noop), ('dns1', 'dns1', mapper.Noop), ('dn
      s2', 'dns2', mapper.Noop), ('gateway', 'gateway', mapper.Noop), ('gate
      way_v6', 'gateway_v6', mapper.Noop), ('host', 'host', mapper.Noop), ('
      name', 'label', mapper.Noop), ('mtu', 'mtu', mapper.Noop), ('netmask',
      ...